indexStore.C2IndexStore

|  | ## Cheshire3 Object Model: Class C2IndexStore

Module indexStore :: Class C2IndexStore

## Class C2IndexStore
source code

Object Tree:

               object --+
                        |
    configParser.C3Object --+
                            |
       baseObjects.IndexStore --+
                                |
                    BdbIndexStore --+
                                    |
                                   C2IndexStore

Use C2 style indexes, only one recordStore
Instance Methods

Inherited from `BdbIndexStore`: `__init__`, `begin_indexing`, `clean_index`, `commit_indexing`, `commit_indexing2`, `contains_index`, `create_index`, `create_item`, `create_term`, `delete_index`, `delete_terms`, `fetch_indexList`, `fetch_indexStats`, `fetch_packed`, `fetch_sortValue`, `fetch_temp_file`, `fetch_term`, `fetch_termList`, `get_indexingPosition`, `store_terms` Inherited from `BdbIndexStore` (private): `_closeIndex`, `_fileFilter`, `_generateFilename`, `_get_externalId`, `_get_internalId`, `_openIndex` Inherited from `configParser.C3Object`: `auth_function`, `get_config`, `get_default`, `get_object`, `get_path`, `get_setting`, `log_function`, `unauth_function`, `unlog_function` Inherited from `configParser.C3Object` (private): `_getDomFromFile`, `_handleConfigNode`, `_parseIncludes`, `_recurseSubConfigs`, `_verifyDefault`, `_verifyOption`, `_verifySetting` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables

Inherited from `BdbIndexStore`: `identifierMapCxn`, `indexCxn`, `indexing`, `outFiles`, `outSortFiles`, `reservedLongs`, `sortStoreCxn`, `storeHash`, `storeHashReverse` Inherited from `configParser.C3Object`: `configStore`, `defaults`, `functionLogger`, `id`, `name`, `objectType`, `objects`, `parent`, `paths`, `permissionHandlers`, `settings`, `subConfigs`, `unresolvedObjects` Inherited from `configParser.C3Object` (private): `_includeConfigStores`, `_objectRefs` Inherited from `object`: `__class__`